import chalk from 'chalk';

const timers = /* @__PURE__ */ new Map();
function createLogger(prefix, options = {}) {
  const { level = "info" } = options;
  const formatPrefix = () => chalk.cyan(`[${prefix}]`);
  const formatTime = (ms) => chalk.gray(`(${ms}ms)`);
  return {
    info: (message, ...args) => {
      console.log(`${formatPrefix()} ${message}`, ...args);
    },
    warn: (message, ...args) => {
      console.warn(`${formatPrefix()} ${chalk.yellow("warning")} ${message}`, ...args);
    },
    error: (message, ...args) => {
      console.error(`${formatPrefix()} ${chalk.red("error")} ${message}`, ...args);
    },
    success: (message, ...args) => {
      console.log(`${formatPrefix()} ${chalk.green("\u2713")} ${message}`, ...args);
    },
    report: (stats) => {
      const { total, success, skipped, failed } = stats;
      const hasIssues = failed > 0 || skipped > 0;
      console.log("\n" + formatPrefix() + " " + chalk.bold("Build Summary:"));
      const rows = [
        [`  ${chalk.bold("Total files:")}`, `${total}`],
        [`  ${chalk.bold("Processed:")}`, `${chalk.green(success)}`],
        [`  ${chalk.bold("Skipped:")}`, `${skipped > 0 ? chalk.yellow(skipped) : skipped}`],
        [`  ${chalk.bold("Failed:")}`, `${failed > 0 ? chalk.red(failed) : failed}`]
      ];
      rows.forEach(([label, value]) => {
        console.log(`${label.padEnd(20)}${value}`);
      });
      if (hasIssues) {
        console.log("\n" + formatPrefix() + " " + chalk.yellow("\u26A0\uFE0F  Some files were not processed successfully"));
      } else {
        console.log("\n" + formatPrefix() + " " + chalk.green("\u2728 All files processed successfully"));
      }
      console.log();
    },
    time: (label) => {
      timers.set(label, performance.now());
    },
    timeEnd: (label) => {
      const start = timers.get(label);
      if (start) {
        const duration = Math.round(performance.now() - start);
        console.log(`${formatPrefix()} ${label} ${formatTime(duration)}`);
        timers.delete(label);
      }
    },
    verbose: (message, ...args) => {
      if (level === "verbose") {
        console.log(`${formatPrefix()} ${chalk.gray(message)}`, ...args);
      }
    }
  };
}

export { createLogger };
//# sourceMappingURL=logger.js.map
//# sourceMappingURL=logger.js.map